Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2008-10-07 20:35:52 +0000
committerStijn Buys <ingar@osirion.org>2008-10-07 20:35:52 +0000
commitbc50666e86d5739ccde633eb630cc75b3e0fcb71 (patch)
treeafad7eb043d6773a7b2a426f4d7b1f600301b5cd /src/ui/button.h
parentf54bd48a884e4e3c95818f042a4b2418a6e070a4 (diff)
libui updates
Diffstat (limited to 'src/ui/button.h')
-rw-r--r--src/ui/button.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/ui/button.h b/src/ui/button.h
index bdf310b..34c3ba4 100644
--- a/src/ui/button.h
+++ b/src/ui/button.h
@@ -25,14 +25,15 @@ public:
/// print button description
virtual void print(size_t indent);
- /// handle keyboard input
- virtual void event_keypress(unsigned int key, unsigned int modifier);
- virtual void event_keyrelease(unsigned int key, unsigned int modifier);
+ /// handle keyboard events
+ virtual void keypress(unsigned int key, unsigned int modifier);
+ virtual void keyrelease(unsigned int key, unsigned int modifier);
protected:
- virtual void draw();
+ /// draw the button border
+ virtual void draw_border();
- /// draw the button
+ /// draw the button text
virtual void draw_text();
private: